import enum

from sqlalchemy import Column, Integer, String, TIMESTAMP, Text, ForeignKey, Enum, UniqueConstraint, func
from sqlalchemy.orm import relationship

from .base import Base


class BookStatusEnum(enum.Enum):
    available = 'available'
    borrowed = 'borrowed'
    reserved = 'reserved'


class Book(Base):
    __tablename__ = 'book'
    __table_args__ = (UniqueConstraint('isbn'),)

    id = Column(Integer, primary_key=True, autoincrement=True)
    author_id = Column(Integer, ForeignKey('author.id'), nullable=False)
    title = Column(String(100), nullable=False)
    description = Column(Text, nullable=False)
    year_published = Column(String(4), nullable=False)
    isbn = Column(String(13), nullable=False, unique=True)
    status = Column(Enum(BookStatusEnum), nullable=False, default=BookStatusEnum.available)
    created_at = Column(TIMESTAMP, nullable=False, server_default=func.now())
    last_updated = Column(TIMESTAMP, nullable=False, server_default=func.now())

    # Reference 'Author' as a string to avoid direct import
    author = relationship('Author', back_populates='books')
